@@ -626,7 +626,7 @@ function TroveMarker:check_veto(marker, pname)
   elseif toll.nopiety then
     local yesno_message = (
       "This portal proclaims the superiority of the material over the divine; "
-      .. "those who enter it will find they have lost all favor with their "
+      .. "those who enter it will find they have lost all favour with their "
       .. "chosen deity. Enter anyway?")
     if crawl.yesno(yesno_message, true, "n") then
       self:accept_nopiety()
